@@ -1,16 +1,5 @@
-from authorizenet.apicontrollers import (
-    createCustomerProfileController,
-    deleteCustomerProfileController,
-    getCustomerProfileController,
-    updateCustomerProfileController,
-)
-from authorizenet.apicontractsv1 import (
-    customerProfileType,
-    createCustomerProfileRequest,
-    deleteCustomerProfileRequest,
-    getCustomerProfileRequest,
-    updateCustomerProfileRequest,
-)
+from authorizenet import apicontractsv1, apicontrollers
+from authorizenet.apicontractsv1 import customerProfileType
 
 from terminusgps.authorizenet.profiles.base import AuthorizenetProfileBase
 
@@ -31,15 +20,16 @@ class CustomerProfile(AuthorizenetProfileBase):
         if not kwargs.get("email"):
             raise ValueError("'email' is required for creation.")
 
-        return self._authorizenet_create_customer_profile(
-            kwargs["email"], kwargs.get("desc", "")
+        response = self._authorizenet_create_customer_profile(
+            email=kwargs["email"], desc=kwargs.get("desc", "")
         )
+        return int(response.customerProfileId)
 
-    def update(self, email: str, desc: str = "") -> None:
+    def update(self, email: str, desc: str = "") -> dict:
         """Updates the customer profile."""
         return self._authorizenet_update_customer_profile(email, desc)
 
-    def delete(self) -> None:
+    def delete(self) -> dict:
         """Deletes the customer profile."""
         return self._authorizenet_delete_customer_profile()
 
@@ -57,9 +47,11 @@ class CustomerProfile(AuthorizenetProfileBase):
         )
         return addresses if addresses else None
 
-    def _authorizenet_create_customer_profile(self, email: str, desc: str = "") -> int:
+    def _authorizenet_create_customer_profile(
+        self, email: str, desc: str = ""
+    ) -> dict[str, str]:
         """Executes a :py:obj:`~authorizenet.apicontractsv1.createCustomerProfileRequest` using the Authorize.NET API."""
-        request = createCustomerProfileRequest(
+        request = apicontractsv1.createCustomerProfileRequest(
             merchantAuthentication=self.merchantAuthentication,
             profile=customerProfileType(
                 merchantCustomerId=self.merchantCustomerId,
@@ -67,36 +59,28 @@ class CustomerProfile(AuthorizenetProfileBase):
                 description=desc,
             ),
         )
-        controller = createCustomerProfileController(request)
+        controller = apicontrollers.createCustomerProfileController(request)
         response = self.execute_controller(controller)
-        return int(response.customerProfileId)
-
-    def _authorizenet_delete_customer_profile(self) -> None:
-        """Executes a :py:obj:`~authorizenet.apicontractsv1.deleteCustomerProfileRequest` using the Authorize.NET API."""
-        assert self.id, "'id' was not set."
-        request = deleteCustomerProfileRequest(
-            merchantAuthentication=self.merchantAuthentication,
-            customerProfileId=str(self.id),
-        )
-        controller = deleteCustomerProfileController(request)
-        self.execute_controller(controller)
+        return response
 
     def _authorizenet_get_customer_profile(self, issuer_info: bool = True) -> dict:
         """Executes a :py:obj:`~authorizenet.apicontractsv1.getCustomerProfileRequest` using the Authorize.NET API."""
         assert self.id, "'id' was not set."
-        request = getCustomerProfileRequest(
+
+        request = apicontractsv1.getCustomerProfileRequest(
             merchantAuthentication=self.merchantAuthentication,
             customerProfileId=self.id,
             includeIssuerInfo=str(issuer_info).lower(),
         )
-        controller = getCustomerProfileController(request)
+        controller = apicontrollers.getCustomerProfileController(request)
         response = self.execute_controller(controller)
         return response
 
-    def _authorizenet_update_customer_profile(self, email: str, desc: str = "") -> None:
+    def _authorizenet_update_customer_profile(self, email: str, desc: str = "") -> dict:
         """Executes an :py:obj:`~authorizenet.apicontractsv1.updateCustomerProfileRequest` using the Authorize.NET API."""
         assert self.id, "'id' was not set."
-        request = updateCustomerProfileRequest(
+
+        request = apicontractsv1.updateCustomerProfileRequest(
             merchantAuthentication=self.merchantAuthentication,
             profile=customerProfileType(
                 merchantCustomerId=self.merchantCustomerId,
@@ -105,5 +89,18 @@ class CustomerProfile(AuthorizenetProfileBase):
                 customerProfileId=self.id,
             ),
         )
-        controller = updateCustomerProfileController(request)
-        self.execute_controller(controller)
+        controller = apicontrollers.updateCustomerProfileController(request)
+        response = self.execute_controller(controller)
+        return response
+
+    def _authorizenet_delete_customer_profile(self) -> dict:
+        """Executes a :py:obj:`~authorizenet.apicontractsv1.deleteCustomerProfileRequest` using the Authorize.NET API."""
+        assert self.id, "'id' was not set."
+
+        request = apicontractsv1.deleteCustomerProfileRequest(
+            merchantAuthentication=self.merchantAuthentication,
+            customerProfileId=self.id,
+        )
+        controller = apicontrollers.deleteCustomerProfileController(request)
+        response = self.execute_controller(controller)
+        return response
